@@ -54,12 +54,17 @@ class Status:
                             "enabled": self.father.framework.machine.info["spindle"][0]["enabled"],
                             "direction": self.father.framework.machine.info["spindle"][0]["direction"],
                             "speed": self.father.framework.machine.info["spindle"][0]["speed"],
+                            "max_speed": int(self.father.framework.machine.get_user_config_value("SPINDLE", "MAX_SPEED") or 24000),
                             "default_speed": int(inifile.find("DISPLAY", "DEFAULT_SPINDLE_SPEED")),
                             "min_override": float(inifile.find("DISPLAY", "MIN_SPINDLE_OVERRIDE")),
                             "max_override": float(inifile.find("DISPLAY", "MAX_SPINDLE_OVERRIDE")),
                             "override": self.father.framework.machine.info["spindle"][0]["override"],
                             "override_enabled": self.father.framework.machine.info["spindle"][0]["override_enabled"]
                         },
+                        "feed": {
+                            "max_override": float(inifile.find("DISPLAY", "MAX_FEED_OVERRIDE")),
+                        },
+                        "ext_info": self.father.framework.machine.get_user_config_items("EXTINFO")
                     }
 
                     self.father.framework.machine.info["user_data"] = user_data
